@@ -26,18 +26,11 @@ __all__ = ['AnalyzeThread',
            'LogfileAnalyzer',
           ]
 
-import errno as Errno
 import gobject
 import os
-import Queue
-import signal
-from stat import *
-import re
-import sys
 import time
 import threading
-import commands
-from types import *
+from stat import *
 
 from setroubleshoot.config import get_config
 from setroubleshoot.avc_audit import *
@@ -168,7 +161,7 @@ class Analyze(object):
 
         if profile:
             statistics.end()
-            log_stats.info("analyze_avc() audit_event=%s\nstatistics=%s", audit_event, statistics)
+            log_stats.info("analyze_avc() avc=%s statistics=%s", avc, statistics)
     
 #------------------------------------------------------------------------------
 
@@ -373,8 +366,9 @@ class SETroubleshootDatabase(object):
                           len(matches), ",".join(["%.2f" % x.score for x in matches]))
         if len(matches) == 0:
             raise ProgramError(ERR_NO_SIGNATURE_MATCH)
-        elif len(matches) > 1:
-            raise ProgramError(ERR_MULTIPLE_SIGNATURE_MATCH)
+        if len(matches) > 1:
+            log_sig.warning("lookup_signature: found %d matches with scores %s",
+                            len(matches), ",".join(["%.2f" % x.score for x in matches]))
         siginfo = matches[0].siginfo
         return siginfo
 
@@ -557,11 +551,10 @@ class LogfileAnalyzer(gobject.GObject):
             self.file = open(self.logfile_path)
             self.fileno = self.file.fileno()
         except EnvironmentError, e:
-            log_avc.error('%s.open()', self.__class__.__name__, e.strerror)
+            log_avc.error('%s.open(): %s', self.__class__.__name__, e.strerror)
             self.errno = e.errno
             self.strerror = e.strerror
-            self.emit('state-changed', 'stopped')
-            return False
+            raise e
 
         self.n_bytes_read = 0
         self.line_count = 0
@@ -597,6 +590,7 @@ class LogfileAnalyzer(gobject.GObject):
             self.fileno = None
 
         if self.n_bytes_read != self.file_size:
+            import errno as Errno
             strerror = "failed to read complete file, %d bytes read out of total %d bytes (%s)" % \
                        (self.n_bytes_read, self.file_size, self.logfile_path)
             log_avc.warn(strerror)
