@@ -1,6 +1,6 @@
 # Authors: John Dennis <jdennis@redhat.com>
-#
-# Copyright (C) 2007 Red Hat, Inc.
+#          Thomas Liu <tliu@redhat.com
+# Copyright (C) 2007,2008,2009 Red Hat, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,10 +30,9 @@ __all__ = ['derive_record_format',
            ]
 
 import audit
-import copy
+import struct
 import os
 import re
-import struct
 import selinux
 from types import *
 
@@ -211,6 +210,7 @@ class AuditEventID(XmlSerialize):
         return 0
     
     def copy(self):
+        import copy
         return copy.copy(self)
 
     time = property(lambda self: float(self.sec) + self.milli / 1000.0)
@@ -682,9 +682,9 @@ class AVC:
         path = self.avc_record.get_field('path')
 
         if path is None:
-            avc_path_record = self.audit_event.get_record_of_type('AVC_PATH')
+            avc_path_record = self.audit_event.get_record_of_type('PATH')
             if avc_path_record:
-                path = avc_path_record.get_field('path')
+                path = avc_path_record.get_field('name')
             
         if path is None:
             # No path field, so try and use the name field instead
@@ -694,18 +694,33 @@ class AVC:
                 tclass = self.avc_record.get_field('tclass')
                 if tclass   == 'file':
                     # file name is not a full path so make it appear relative
-                    path = './%s' % name
+                    path = '%s' % name
                 elif tclass == 'dir':
                     # directory component is not a full path so make it appear
                     # relative, but only if it's not the root
                     if name == '/':
                         path = name
                     else:
-                        path = './%s' % name
+                        path = '%s' % name
                 else:
                     # just use the bare name
                     path = name
 
+        if path is not None:
+            if path.startswith("/") == False:
+                import commands
+                command = "locate -b '\%s'" % path 
+                rc, output = commands.getstatusoutput(command)
+                if rc == 0:
+                    inode = int(self.avc_record.get_field("ino"))
+                    for file in output.split("\n"):
+                        try:
+                            if int(os.stat(file).st_ino) == inode:
+                                path = file
+                                break
+                        except:
+                            pass
+
         if path is not None:
             if path.startswith('/'):
                 # Fully qualified path
