@@ -32,7 +32,6 @@ import sys
 import os
 import ConfigParser
 import re
-import textwrap
 
 _cfg = None
 
@@ -55,7 +54,7 @@ defaults = {
         'readOnly'    : True,
     },
     'pkg_version' : {
-        'value'       : '2.0.12',
+        'value'       : '2.1.14',
         'description' : '',
         'readOnly'    : True,
     },
@@ -141,34 +140,34 @@ for a specific alert, this parameter does not override that.''',
 },
 'session_dbus' : {
     'bus_name' : {
-        'value'       : 'com.redhat.setroubleshoot',
+        'value'       : 'org.fedoraproject.Setroubleshootd',
         'description' : '',
         'readOnly'    : True,
     },
     'object_path' : {
-        'value'       : '/com/redhat/selinux/alert_object',
+        'value'       : '/org/fedoraproject/Setroubleshootd',
         'description' : '',
         'readOnly'    : True,
     },
     'interface' : {
-        'value'       : 'com.redhat.SEtroubleshootIface',
+        'value'       : 'org.fedoraproject.SetroubleshootdIface',
         'description' : '',
         'readOnly'    : True,
     },
 },
 'system_dbus' : {
     'bus_name' : {
-        'value'       : 'com.redhat.setroubleshootd',
+        'value'       : 'org.fedoraproject.Setroubleshootd',
         'description' : '',
         'readOnly'    : True,
     },
     'object_path' : {
-        'value'       : '/com/redhat/setroubleshootd',
+        'value'       : '/org/fedoraproject/Setroubleshootd',
         'description' : '',
         'readOnly'    : True,
     },
     'interface' : {
-        'value'       : 'com.redhat.SEtroubleshootdIface',
+        'value'       : 'org.fedoraproject.SetroubleshootdIface',
         'description' : '',
         'readOnly'    : True,
     },
@@ -577,6 +576,7 @@ def config_has_section(section):
     
 
 def dump_defaults(defaults, showReadOnly=False):
+    import textwrap
     wrap = textwrap.TextWrapper(width=78,
                                 initial_indent='# ', subsequent_indent='# ')
 
