@@ -22,11 +22,7 @@ __all__ = ["RunCmdGUI",
 
 import os
 import signal
-import shlex
-import sys
-import termios
-import errno
-import re
+#import sys
 
 def wait_status(status):
     exit_status = (status >> 8) & 0xFF
@@ -65,6 +61,7 @@ TERMIOS_IFLAG, TERMIOS_OFLAG, TERMIOS_CFLAG, TERMIOS_LFLAG, TERMIOS_ISPEED, TERM
 #------------------------------------------------------------------------
 
 def set_raw_input(fd):
+    import termios
     old = termios.tcgetattr(fd)
     new = termios.tcgetattr(fd)
 
@@ -212,6 +209,7 @@ class TTYView(gtk.Bin):
 	self.hide()
 
     def append_text(self, text):
+        import re
 	if re.search('password:', text, re.IGNORECASE):
 	    dlg = PasswordDialog(text)
 	    rc = dlg.run()
@@ -334,6 +332,7 @@ class IO_Watch:
 		if data == '':
 		    return False
 	    except OSError, e:
+                import errno
 		if e.errno == errno.EINTR:
 		    return True
 	    else:
@@ -559,6 +558,7 @@ class RunCmdGUI(object):
         set_raw_input(self.tty_master_fd)
 
 	try:
+            import shlex
 	    self.pid, self.stdin_fd, self.stdout_fd, self.stderr_fd = \
 		      gobject.spawn_async(shlex.split(self.cmd),
 					  standard_output=True, standard_error=True,
