@@ -1,6 +1,7 @@
 # Authors: John Dennis <jdennis@redhat.com>
+#          Dan Walsh <dwalsh@redhat.com>
 #
-# Copyright (C) 2006,2007,2008 Red Hat, Inc.
+# Copyright (C) 2006-2009 Red Hat, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,36 +28,64 @@ __all__ = ['RunFaultServer',
 
 import gobject
 gobject.threads_init()
-from dbus import glib
+import dbus
 import dbus.service
-import errno as Errno
+import dbus.glib
+#import errno as Errno
 import os
-import pwd
-import Queue
+#import pwd
 import signal
-from stat import *
-import sys
+import atexit
+#from stat import *
 import syslog
-import time
-import threading
-from types import *
+#import threading
+#from types import *
 
-from setroubleshoot.access_control import *
-from setroubleshoot.analyze import *
+from setroubleshoot.access_control import ServerAccess
+from setroubleshoot.analyze import (PluginReportReceiver,
+                                    SETroubleshootDatabase,
+                                    TestPluginReportReceiver,
+                                    AnalyzeThread, 
+                                    )                                
+from setroubleshoot.avc_audit import *
 from setroubleshoot.config import get_config
 if get_config('general', 'use_auparse', bool):
     from setroubleshoot.avc_auparse import *
 else:
-    from setroubleshoot.avc_audit import *
-from setroubleshoot.errcode import *
-from setroubleshoot.email_alert import *
-from setroubleshoot.log import *
-from setroubleshoot.rpc import *
-from setroubleshoot.rpc_interfaces import *
-from setroubleshoot.signature import *
-from setroubleshoot.util import *
-from setroubleshoot.html_util import *
-
+    from setroubleshoot.avc_audit import AuditRecordReceiver
+    
+from setroubleshoot.errcode import (ProgramError,
+                                    ERR_NOT_AUTHENTICATED, 
+                                    ERR_USER_LOOKUP, 
+                                    ERR_USER_PROHIBITED, 
+                                    ERR_USER_PERMISSION, 
+                                    ERR_FILE_OPEN, 
+                                    ERR_DATABASE_NOT_FOUND, 
+                                    )
+                                    
+from setroubleshoot.log import (debug, 
+                                log_server,
+                                log_rpc,
+                                log_email,
+                                log_communication,
+                                log_alert, 
+                                )
+                                
+from setroubleshoot.rpc import (RpcChannel,
+                                ConnectionState, 
+                                get_socket_list_from_config, 
+                                ListeningServer, 
+                                )
+                                
+from setroubleshoot.rpc_interfaces import (SETroubleshootServerInterface,
+                                           SETroubleshootDatabaseNotifyInterface, 
+                                           SEAlertInterface, 
+                                           )
+from setroubleshoot.util import (get_hostname, 
+                                 make_database_filepath, 
+                                 assure_file_ownership_permissions, 
+                                 get_identity, 
+                                 )
 #------------------------------ Utility Functions -----------------------------
     
 
@@ -68,10 +97,11 @@ def sighandler(signum, frame):
         log_server.warning("reloading configuration file")
         config.config_init()
         return
-    
+    import sys    
     sys.exit()
 
 def make_instance_id():
+    import time
     hostname = get_hostname()
     pid = os.getpid()
     stamp = str(time.time())
@@ -80,8 +110,19 @@ def make_instance_id():
 def get_host_database():
     return host_database
 
+dbus_system_bus_name = get_config('system_dbus','bus_name')
+dbus_system_object_path = get_config('system_dbus','object_path')
+dbus_system_interface = get_config('system_dbus','interface')
+
+system_bus = dbus.SystemBus()
+system_bus.request_name(dbus_system_bus_name)
+
 # FIXME: this should be part of ClientNotifier
 def send_alert_notification(siginfo):
+    alert=dbus.lowlevel.SignalMessage(dbus_system_object_path, dbus_system_interface, "alert");
+    alert.append(siginfo.level)
+    system_bus.send_message(alert)
+
     for client in connection_pool.clients('sealert'):
         client.alert(siginfo)
 
@@ -122,8 +163,9 @@ class ConnectionPool(object):
                 yield client
 
     def close_all(self, channel_type=None):
-        for client in self.client_pool(channel_type):
-            client.close_connection()
+        for client in self.client_pool:
+            if client.channel_type == channel_type:
+                client.close_connection()
 
 connection_pool = ConnectionPool()
 
@@ -147,13 +189,16 @@ class AlertPluginReportReceiver(PluginReportReceiver):
                     to_addrs.append(recipient.address)
 
             if len(to_addrs):
+                from setroubleshoot.email_alert import email_alert
                 email_alert(siginfo, to_addrs)
         
         if debug:
             log_alert.debug("sending alert to all clients")
+
         send_alert_notification(siginfo)
 
         # FIXME: should this be using our logging objects in log.py?
+        from setroubleshoot.html_util import html_to_text
         summary = html_to_text(siginfo.solution.summary, 1024)
         syslog.syslog(summary + _(" For complete SELinux messages. run sealert -l %s" % siginfo.local_id ))
         return siginfo
@@ -379,35 +424,81 @@ class ClientNotifier(object):
 
 
 #------------------------------------------------------------------------------
-
-dbus_system_bus_name = get_config('system_dbus','bus_name')
-dbus_system_object_path = get_config('system_dbus','object_path')
-dbus_system_interface = get_config('system_dbus','interface')
+from setroubleshoot.audit_data import *
 
 class SetroubleshootdDBusObject(dbus.service.Object):
-    def __init__(self, bus_name, object_path):
-        dbus.service.Object.__init__(self, bus_name, object_path)
+    def __init__(self, object_path, analysis_queue, alert_receiver):
+        dbus.service.Object.__init__(self, dbus.SystemBus(), object_path)
+        self.conn_ctr=0
+        self.alarm()
+        log_server.debug('dbus __init__ %s called' % object_path)
+        self.queue = analysis_queue
+        self.receiver = alert_receiver
+        self.record_reader = AuditRecordReader(AuditRecordReader.TEXT_FORMAT)
+        self.record_receiver = AuditRecordReceiver()
 
     @dbus.service.signal(dbus_system_interface)
     def restart(self, reason):
         pass
 
+    @dbus.service.method(dbus_system_interface)
+    def start(self):
+        self.alarm(0)
+        self.conn_ctr += 1
+        log_server.debug('dbus iface start() called: %d Connections' % self.conn_ctr)
+        return _("Started")
+
+    @dbus.service.method(dbus_system_interface, in_signature='s',  out_signature='s')
+    def avc(self, data):
+        self.alarm(0)
+        self.conn_ctr += 1
+        log_server.debug('dbus avc(%s) called: %d Connections' % (data, self.conn_ctr))
+        for (record_type, event_id, body_text, fields, line_number) in self.record_reader.feed(str(data)):
+            audit_record = AuditRecord(record_type, event_id, body_text, fields, line_number)
+            audit_record.audispd_rectify()
+            
+            for audit_event in self.record_receiver.feed(audit_record):
+                avc = AVC(audit_event)
+                if verify_avc(avc):
+                    self.queue.put((avc, self.receiver))
+
+        for audit_event in self.record_receiver.flush(0):
+            avc = AVC(audit_event)
+            if verify_avc(avc):
+                self.queue.put((avc, self.receiver))
+
+        self.conn_ctr -= 1
+        self.alarm()
+        return _("AVC")
+
+    @dbus.service.method(dbus_system_interface)
+    def finish(self):
+        self.conn_ctr -= 1
+        log_server.debug('dbus iface finish() called: %d Connections' % self.conn_ctr)
+        self.alarm()
+        return ""
+
+    def alarm(self, timeout = 10):
+        if self.conn_ctr == 0:
+            signal.alarm(timeout) 
+
 class SetroubleshootdDBus:
-    def __init__(self):
+    def __init__(self, analysis_queue, alert_receiver):
         try:
             log_server.info("creating system dbus: bus_name=%s object_path=%s interface=%s",
                             dbus_system_bus_name, dbus_system_object_path, dbus_system_interface)
-            self.bus = dbus.SystemBus()
-            self.bus_name = dbus.service.BusName(dbus_system_bus_name, bus=self.bus)
-            self.dbus_obj = SetroubleshootdDBusObject(self.bus_name, dbus_system_object_path)
+            self.dbus_obj = SetroubleshootdDBusObject(dbus_system_object_path, analysis_queue, alert_receiver)
         except Exception, e:
-            log_server.error("cannot start systen DBus service: %s" % e)
+            log_server.error("cannot start system DBus service: %s" % e)
+            raise e
 
     def do_restart(self):
         self.dbus_obj.restart("daemon request")
         return True
 
 #------------------------------------------------------------------------------
+def goodbye(database):
+    database.save()
 
 def RunFaultServer():
     # FIXME
@@ -416,6 +507,7 @@ def RunFaultServer():
     signal.signal(signal.SIGHUP, sighandler)
     signal.signal(signal.SIGQUIT, sighandler)
     signal.signal(signal.SIGTERM, sighandler)
+    signal.signal(signal.SIGALRM, sighandler)
 
     #interface_registry.dump_interfaces()
 
@@ -431,7 +523,7 @@ def RunFaultServer():
         client_notifier = ClientNotifier(connection_pool)
 
         # Create a database local to this host
-
+        
         database_filename = get_config('database','filename')
         database_filepath = make_database_filepath(database_filename)
         assure_file_ownership_permissions(database_filepath, 0600, 'root', 'root')
@@ -439,6 +531,8 @@ def RunFaultServer():
                                                friendly_name=_("Audit Listener"))
         host_database.set_notify(client_notifier)
 
+        atexit.register(goodbye, host_database)
+
         # Attach the local database to an object which will send alerts
         # specific to this host
 
@@ -448,7 +542,7 @@ def RunFaultServer():
             alert_receiver = TestPluginReportReceiver(host_database)
 
         # Create a synchronized queue for analysis requests
-
+        import Queue
         analysis_queue = Queue.Queue(0)
 
         # Create a thread to peform analysis, it takes AVC objects off
@@ -471,11 +565,12 @@ def RunFaultServer():
         # analysis queue where another thread will process it
         # independently.
 
-        audit_socket_thread = AuditSocketReceiverThread(analysis_queue, alert_receiver)
-        audit_socket_thread.setDaemon(True)
-        audit_socket_thread.start()
+#        audit_socket_thread = AuditSocketReceiverThread(analysis_queue, alert_receiver)
+#        audit_socket_thread.setDaemon(True)
+#        audit_socket_thread.start()
 
         # Initialize the email recipient list
+        from setroubleshoot.signature import SEEmailRecipientSet
         email_recipients = SEEmailRecipientSet()
         assure_file_ownership_permissions(email_recipients_filepath, 0600, 'root', 'root')
         try:
@@ -492,8 +587,8 @@ def RunFaultServer():
             listening_server = ListeningServer(listen_address, SetroubleshootdClientConnectionHandler)
             listening_server.open()
 
-        setroubleshootd_dbus = SetroubleshootdDBus()
-        
+        dbus.glib.init_threads()
+        setroubleshootd_dbus = SetroubleshootdDBus(analysis_queue, alert_receiver)
         main_loop = gobject.MainLoop()
         main_loop.run()
 
@@ -506,7 +601,7 @@ def RunFaultServer():
             log_server.debug("raising SystemExit in RunFaultServer")
 
     except Exception, e:
-        log_rpc.exception("exception %s: %s",e.__class__.__name__, str(e))
+        log_rpc.exception("exception %s: %s", e.__class__.__name__, str(e))
 
 if __name__=='__main__':
     RunFaultServer()
